@@ -35,7 +35,7 @@ def search_lines(file_path, f_filter, start_from=0):
 
 if __name__ == "__main__":
 
-    _file_path = '/Users/gideonbar/tmp/DockingBot.pm'
+    _file_path = 'DockingBot'
 
     search_lines(_file_path, equal_filter, 1602)
 
